==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGridHeaderTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeaderTypeDescriptionMetadata } from "./WebHeaderTypeDescriptionMetadata";
import { WebGridHeaderTemplateContextDescription } from "./WebGridHeaderTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridHeaderTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridHeaderTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridHeaderTemplateContextDescriptionMetadata.a == null) {
                WebGridHeaderTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridHeaderTemplateContextDescriptionMetadata.c(WebGridHeaderTemplateContextDescriptionMetadata.a);
            }
            if (a.j(WebGridHeaderTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridHeaderTemplateContextDescriptionMetadata.a);
            WebHeaderTypeDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridHeaderTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Implicit", "ExportedType:WebHeaderType");
        }
        static d(a) {
            WebGridHeaderTemplateContextDescriptionMetadata.b(a);
            a.aa("WebGridHeaderTemplateContext", () => new WebGridHeaderTemplateContextDescription());
            a.z("WebGridHeaderTemplateContext", WebGridHeaderTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridHeaderTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridHeaderTemplateContextDescriptionMetadata, 'WebGridHeaderTemplateContextDescriptionMetadata');
    WebGridHeaderTemplateContextDescriptionMetadata.a = null;
    return WebGridHeaderTemplateContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridHeaderTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeaderTypeDescriptionMetadata } from "./WebHeaderTypeDescriptionMetadata";
import { WebGridHeaderTemplateContextDescription } from "./WebGridHeaderTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridHeaderTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridHeaderTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridHeaderTemplateContextDescriptionMetadata.a == null) {
                WebGridHeaderTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridHeaderTemplateContextDescriptionMetadata.c(WebGridHeaderTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebGridHeaderTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridHeaderTemplateContextDescriptionMetadata.a);
            WebHeaderTypeDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridHeaderTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebHeaderType");
        }
        static d(a) {
            WebGridHeaderTemplateContextDescriptionMetadata.b(a);
            a.ac("WebGridHeaderTemplateContext", () => new WebGridHeaderTemplateContextDescription());
            a.ab("WebGridHeaderTemplateContext", WebGridHeaderTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridHeaderTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridHeaderTemplateContextDescriptionMetadata, 'WebGridHeaderTemplateContextDescriptionMetadata');
    WebGridHeaderTemplateContextDescriptionMetadata.a = null;
    return WebGridHeaderTemplateContextDescriptionMetadata;
})();
